#######################################################################################
# File to be "sourced" or "included" in each of Ted's R code files.  This file is the
# first file that is sourced in Ted's R code, and it defines some things used by other
# files that may be sourced after this one.
#
# To use this file, source it as the first statements in an R program, as follows:
#
#   # Include the root R source code file.
#   R_INCLUDE_DIR = Sys.getenv("R_INCLUDE_DIR")
#   if (R_INCLUDE_DIR == "")
#       stop("Set environment variable R_INCLUDE_DIR or assign that variable to a path here.")
#   source(paste(R_INCLUDE_DIR, "Include_RootRsourceFile.R", sep=""))
#
# Notice the use of variable "R_INCLUDE_DIR".  It must be the path where THIS
# file is located, ending in a path separator character ("/" for Mac/Linux, "\"
# for Windows).  You can set it either by defining an shell environment variable
# with the same name, or, if you don't know how to do that, just set it directly
# as follows, instead of the above statement that uses Sys.getenv():
#
#   R_INCLUDE_DIR = "~/Documents/BradyLab/Rcode/"
#
# Author: Ted Toal
# Lab: Brady
# Date: May 2015
#######################################################################################

cat("Including Include_RootRsourceFile.R\n")

#######################################################################################
# Get file path separator character, is either "/" (Mac/Linux) or "\" (Windows).
#######################################################################################
PATHSEP = substr(dir(pattern="^.*\\.*$", full.names=TRUE)[1], 2, 2)

#######################################################################################
# Include customizations R file.
#######################################################################################

source(paste(R_INCLUDE_DIR, "Include_Customizations.R", sep=""))

#######################################################################################
# This function is used by sourced R files to test if other R files that they require
# have already been sourced, and if not, to stop with an error.  Each R source (include)
# file defines a variable of the form "Sourced_(file name) = TRUE" to indicate that it
# has been sourced.
#
# To use this, if you make a new R "source" file and it requires OTHER R "source"
# files to be sourced, call this function in the new R source file for each such
# other file, to make sure it has been sourced.
#
# Arguments:
#   fileName: Basic name of the file to be sourced, equal to the (file name) value in
#       the "Sourced_(file name)" variable that the file defines to indicate it has
#       been sourced.  See bottom of this file for an example.  Leave off ".R".
#   myFileName: Basic name of the file that is calling this function, for display
#       in error message.
#######################################################################################

requireSourced = function(fileName, myFileName)
    {
    varName = paste("Sourced.", fileName, sep="")
    if (!exists(varName))
        stop(myFileName, ".R requires that ", fileName, ".R be sourced", call.=FALSE)
    }

#######################################################################################
# This function is used by sourced R files to test if R packages that they require
# have already been installed and loaded, and if not, to stop with an error.
#
# To use this, if you make a new R "source" file and it requires R packages, call
# this function in the new R source file for each such package, to make sure it
# has been installed and loaded.
#
# Arguments:
#   package: Package name.
#   myFileName: Basic name of the file that is calling this function, for display
#       in error message.
#######################################################################################

requirePackage = function(package, myFileName)
    {
    if (!(package %in% installed.packages()[,"Package"]))
        stop(myFileName, ".R requires that package ", package, " be installed", call.=FALSE)
    else if ( !( paste("package", package, sep = ":") %in% search() ) )
        stop(myFileName, ".R requires that package ", package, " be loaded", call.=FALSE)
    }

#######################################################################################
# End of file.
#######################################################################################
Sourced.Include_RootRsourceFile = TRUE
cat("  Include_RootRsourceFile.R included\n")
